summaryrefslogtreecommitdiff
path: root/src/mongo/rpc/metadata.h
diff options
context:
space:
mode:
authorMark Benvenuto <mark.benvenuto@mongodb.com>2016-07-26 15:23:10 -0400
committerMark Benvenuto <mark.benvenuto@mongodb.com>2016-07-26 15:23:51 -0400
commit1febb4ceb0e59743b0a49af35db10c4c689aa130 (patch)
tree431445a395fd4fbd1e7c94bf1c4151bba714088d /src/mongo/rpc/metadata.h
parent7daf57f28f564329e92b8779cf12845776b958b3 (diff)
downloadmongo-1febb4ceb0e59743b0a49af35db10c4c689aa130.tar.gz
SERVER-24615 Add support for OperationContext in EgressMetadataHook
Diffstat (limited to 'src/mongo/rpc/metadata.h')
-rw-r--r--src/mongo/rpc/metadata.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/mongo/rpc/metadata.h b/src/mongo/rpc/metadata.h
index b44bdafc13e..9af7bfdfeb5 100644
--- a/src/mongo/rpc/metadata.h
+++ b/src/mongo/rpc/metadata.h
@@ -102,11 +102,13 @@ StatusWith<BSONObj> downconvertReplyMetadata(const BSONObj& commandReply,
const BSONObj& replyMetadata);
/**
* A function type for writing request metadata. The function takes a pointer to a
* BSONObjBuilder used to construct the metadata object and the server address of the
* target of the request and returns a Status indicating if the metadata was written successfully.
*/
-using RequestMetadataWriter = stdx::function<Status(BSONObjBuilder*, StringData)>;
+using RequestMetadataWriter =
+ stdx::function<Status(OperationContext*, BSONObjBuilder*, StringData)>;
/**
* A function type for reading reply metadata. The function takes a a reference to a
@@ -102,11 +102,13 @@ StatusWith<BSONObj> downconvertReplyMetadata(const BSONObj& commandReply,
const BSONObj& replyMetadata);
/**
- * A function type for writing request metadata. The function takes a pointer to a
- * BSONObjBuilder used to construct the metadata object and the server address of the
- * target of the request and returns a Status indicating if the metadata was written successfully.
+ * A function type for writing request metadata. The function takes a pointer to an optional
+ * OperationContext so metadata associated with a Client can be appended, a pointer to a
+ * BSONObjBuilder used to construct the metadata object and the server address of the target of the
+ * request and returns a Status indicating if the metadata was written successfully.
*/